<?php
// www.bcoos.net 2006-09 1.0.2 GPL
// $Id: main.php,v 1.4 2003/03/19 07:04:10 half-dead Exp $
// ------------------------------------------------------------------------- //
//               E-Xoops: Content Management for the Masses                  //
//                       < http://www.e-xoops.com >                          //
// ------------------------------------------------------------------------- //
// Original Author: phpBB Group
// Author Website : http://www.phpbb.com
// License Type   : GPL: See /manual/LICENSES/GPL.txt
// ------------------------------------------------------------------------- //
if ( !preg_match("/admin\.php/i", _PHP_SELF) ) {
	exit();
}
include_once(XOOPS_ROOT_PATH."/modules/system/admin/userrank/userrank.php");
// ------------------------------------------------------------------------- //
$op = !empty($_POST['op']) ? $_POST['op'] : $_GET['op'];
switch($op) {
	case "RankForumAdmin":
		RankForumAdmin();
		break;
	case "RankForumEdit":
		RankForumEdit($rank_id);
		break;
	case "RankForumDel":
		RankForumDel($rank_id, $ok);
		break;
	case "RankForumAdd":
		RankForumAdd($rank_title, $rank_min, $rank_max, $rank_image, $rank_special);
		break;
	case "RankForumSave":
		RankForumSave($rank_id, $rank_title, $rank_min, $rank_max, $rank_image, $rank_special);
		break;
	default:
		RankForumAdmin();
}
?>
